@@ -90,7 +90,11 @@ class OpenAIRequestScheduler:
         self.batch_tokens = 0
         self.batch_size_limit = 2048
         self.batch_token_limit = 400_000
-        self.max_concurrent_requests = 8
+        # TODO: Rate limiting.
+        # This essentially runs a single background thread that processes requests.
+        # This will give a modest performance boost by allowing the main thread to do other tasks.
+        # It would be nice to run requests in parallel for short bursts to make medium-sized project indexing faster.
+        self.max_concurrent_requests = 1
         self.executor = concurrent.futures.ThreadPoolExecutor(
             max_workers=self.max_concurrent_requests,
             thread_name_prefix="OpenAIRequestScheduler"
@@ -108,6 +112,7 @@ class OpenAIRequestScheduler:
             STATS.increment("codebased.embeddings.skipped.too_long")
             return results
         if len(self.batch) >= self.batch_size_limit or self.batch_tokens + request_tokens > self.batch_token_limit:
+            STATS.increment(STATS.Key.index_creation_embedding_tokens_consumed, self.batch_tokens)
             self.futures.append(self.executor.submit(self._process_batch, self.batch))
             self.batch = []
             self.batch_tokens = 0
@@ -714,3 +719,4 @@ class Flags:
     top_k: int
     query: str
     rerank: bool
+    radius: float
